<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\QualityInspectionExpansionData;
use Modules\Qc\Entities\QualityInspectionExpansionHeader;

class QualityInspectionExpansionDataController extends Controller
{
    public function save(Request $request)
    {
        try {
            $rec = new QualityInspectionExpansionHeader();
            $rec->reference_no = $request->get('reference_no');
            $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');          
            $rec->date = $request->get('date');
            $rec->factory = $request->get('factory');
            $rec->user_id = Auth::user()->id;
            if ($rec->save()) {
                $rec_arr = $request->get("qie_data");
                for ($i = 0; $i < count($rec_arr); $i++) {
                    $qieData = json_decode($rec_arr[$i]);

                    $rec_data = new QualityInspectionExpansionData();
                    $rec_data->qi_expansion_id = $rec->qi_expansion_id;
                    $rec_data->hour = $qieData->hour;
                    $rec_data->slab_weight = $qieData->slab_weight;
                    $rec_data->dry_slab_size = $qieData->dry_slab_size;
                    $rec_data->after_expansion_size = $qieData->after_expansion_size;
                    $rec_data->save();
                }
            }
            $responseBody = $this->responseBody(true, "QualityInspectionExpansionDataController", "saved", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "QualityInspectionExpansionDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function update(Request $request, $id)
    {

        try {

            if ($this->delete($id)) {
                $rec = QualityInspectionExpansionHeader::find($id);
                $rec->reference_no = $request->get('reference_no');
                $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');             
                $rec->date = $request->get('date');
                $rec->factory = $request->get('factory');
                $rec->update();

                $rec_arr = $request->get("qie_data");
                if ($rec_arr) {
                    for ($i = 0; $i < count($rec_arr); $i++) {
                        $qieData = json_decode($rec_arr[$i]);
                        $rec_data = new QualityInspectionExpansionData();
                        $rec_data->qi_expansion_id = $rec->qi_expansion_id;
                        $rec_data->hour = $qieData->hour;
                        $rec_data->slab_weight = $qieData->slab_weight;
                        $rec_data->dry_slab_size = $qieData->dry_slab_size;
                        $rec_data->after_expansion_size = $qieData->after_expansion_size;
                        $rec_data->save();
                    }
                }
            }

            $responseBody = $this->responseBody(true, "QualityInspectionExpansionDataController", "update", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "QualityInspectionExpansionDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function delete($id)
    {
        try {
            $rec_data = QualityInspectionExpansionData::where('qi_expansion_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function getQieData($id)
    {
        try {
            $recordHead = QualityInspectionExpansionHeader::find($id);
            $recordData = QualityInspectionExpansionData::where('qi_expansion_id', '=', $id)->get();

            $recordHead->request_data = $recordData;

            $responseBody = $this->responseBody(true, "QualityInspectionExpansionDataController", "getQieData", $recordHead);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "QualityInspectionExpansionDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
