<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\SupervisorCheckListData;
use Modules\Qc\Entities\SupervisorCheckListHeader;
use Modules\Qc\Entities\MaterialTypeRemarks;
use Modules\Qc\Entities\MachineRemarks;

class SupervisorCheckListHeaderController extends Controller
{
    public function allRecords()
    {
        try {
            $query = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_supervisor_check_list_headers.date,
            qc_supervisor_check_list_headers.reference_no,
            qc_supervisor_check_list_headers.scl_id,
            hr_att_shifts.shift_name,
            hr_employee_sites.site
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_supervisor_check_list_headers
            ON
                st_products.product_primary_id = pp_customer_order_plans_data.product_id AND
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_supervisor_check_list_headers.customer_order_plan_data_id
            INNER JOIN
            hr_att_shifts
            ON
                qc_supervisor_check_list_headers.shift_id = hr_att_shifts.shift_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_supervisor_check_list_headers.factory = hr_employee_sites.site_id
        GROUP BY
            qc_supervisor_check_list_headers.scl_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "scl_id" => $record->scl_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "factory" => $record->site,
                    "shift" => $record->shift_name,
                    "date" => $record->date,
                ]);
            }
            $responseBody = $this->responseBody(true, "SupervisorCheckListHeaderController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function deleteRecord($id)
    {
        try {
            if ($this->delete($id)) {
                $rec_data = SupervisorCheckListHeader::where('scl_id', '=', $id)->get();
                foreach ($rec_data as $data) {
                    $data->delete();
                }
                return true;
            }
        } catch (Exception $exception) {
            return false;
        }
    }

    public function delete($id)
    {
        try {
            $rec_data = SupervisorCheckListData::where('scl_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            $rec_data = MaterialTypeRemarks::where('scl_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            $rec_data = MachineRemarks::where('scl_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function supervisorCheckListReport($id)
    {
        try {
            $query1 = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_supervisor_check_list_headers.date,
            qc_supervisor_check_list_headers.reference_no,
            qc_supervisor_check_list_headers.scl_id,
            hr_att_shifts.shift_name,
            hr_employee_sites.site
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_supervisor_check_list_headers
            ON
                st_products.product_primary_id = pp_customer_order_plans_data.product_id AND
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_supervisor_check_list_headers.customer_order_plan_data_id
            INNER JOIN
            hr_att_shifts
            ON
                qc_supervisor_check_list_headers.shift_id = hr_att_shifts.shift_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_supervisor_check_list_headers.factory = hr_employee_sites.site_id
                WHERE
                qc_supervisor_check_list_headers.scl_id = {$id}";

            $records = DB::select($query1);

            $header = [
                "reference_no" => "",
                "product" => "",
                "factory_order_number" => "",
                "date" => "",
                "shift" => "",
                "factory" => "",
            ];


            if ($records) {
                $header["reference_no"] = $records[0]->reference_no;
                $header["product"] = $records[0]->product_name;
                $header["factory_order_number"] = $records[0]->manufacturing_order_no;
                $header["date"] = $records[0]->date;
                $header["shift"] = $records[0]->shift_name;
                $header["factory"] = $records[0]->site;
            }

            $query2 = "SELECT
            qc_supervisor_check_list_data.*
        FROM
            qc_supervisor_check_list_data
        WHERE
            qc_supervisor_check_list_data.scl_id = {$id}";

            $data = DB::select($query2);

            $body = [
                "net_size" => "",
                "siever_magnet" => "",
                "scales_mixing_area" => "",
                "scales_finished_good_area" => "",
                "volume_bucket_accuracy" => "",
                "no_of_qcs" => "",
                "qc_allocated_places" => "",
            ];

            if ($data) {
                $body["net_size"] = $data[0]->net_size;
                $body["siever_magnet"] = $data[0]->siever_magnet;
                $body["scales_mixing_area"] = $data[0]->scales_mixing_area;
                $body["scales_finished_good_area"] = $data[0]->scales_finished_good_area;
                $body["volume_bucket_accuracy"] = $data[0]->volume_bucket_accuracy;
                $body["no_of_qcs"] = $data[0]->no_of_qcs;
                $body["qc_allocated_places"] = $data[0]->qc_allocated_places;
            }

            $query3 = "SELECT
            qc_material_type_remarks.remarks,
            qc_material_types.material_name
        FROM
            qc_supervisor_check_list_headers
            INNER JOIN
            qc_material_type_remarks
            ON
                qc_supervisor_check_list_headers.scl_id = qc_material_type_remarks.scl_id
            INNER JOIN
            qc_material_types
            ON
                qc_material_type_remarks.mt_id = qc_material_types.mt_id
        WHERE
            qc_supervisor_check_list_headers.scl_id = {$id}";

            $materialData = DB::select($query3);

            $query4 = "SELECT
            qc_machine_remarks.remarks,
            pp_machinery.machinery_name
        FROM
            qc_supervisor_check_list_headers
            INNER JOIN
            qc_machine_remarks
            ON
                qc_supervisor_check_list_headers.scl_id = qc_machine_remarks.scl_id
            INNER JOIN
            pp_machinery
            ON
                qc_machine_remarks.machinery_id = pp_machinery.machinery_id
        WHERE
            qc_supervisor_check_list_headers.scl_id = {$id}";

            $machineData = DB::select($query4);


            $responseBody = $this->responseBody(true, "SupervisorCheckListHeaderController", "supervisorCheckListReport", ["header" => $header, "body" => $body, "materialData" => ["data" => $materialData], "machineData" => ["data" => $machineData]]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListHeaderController", "supervisorCheckListReport", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



     /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }

}
